Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(37)

Unified Diff: content/renderer/render_thread_impl.cc

Issue 270633009: [FileAPI] Clean up WebFileSystemImpl before Blink shutdown (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: +clean up on RenderThreadImpl Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/render_thread_impl.cc
diff --git a/content/renderer/render_thread_impl.cc b/content/renderer/render_thread_impl.cc
index eabb5c26714b9e3ab47469aaf8ee11544b5096ac..a368930026412a36dbd25792d2dadabe40d51b32 100644
--- a/content/renderer/render_thread_impl.cc
+++ b/content/renderer/render_thread_impl.cc
@@ -33,6 +33,7 @@
#include "content/child/appcache/appcache_frontend_impl.h"
#include "content/child/child_histogram_message_filter.h"
#include "content/child/db_message_filter.h"
+#include "content/child/fileapi/webfilesystem_impl.h"
#include "content/child/indexed_db/indexed_db_dispatcher.h"
#include "content/child/indexed_db/indexed_db_message_filter.h"
#include "content/child/npapi/npobject_util.h"
@@ -558,9 +559,11 @@ void RenderThreadImpl::Shutdown() {
input_event_filter_ = NULL;
}
// Ramp down IDB before we ramp down WebKit (and V8), since IDB classes might
// hold pointers to V8 objects (e.g., via pending requests).
main_thread_indexed_db_dispatcher_.reset();
+ WebFileSystemImpl::DeleteThreadSpecificInstance();
kinuko 2014/05/08 07:44:09 Should we do this in ChildThread::Shutdown() rathe
tzik 2014/05/08 08:05:30 Done.
if (webkit_platform_support_)
@@ -558,9 +559,11 @@ void RenderThreadImpl::Shutdown() {
input_event_filter_ = NULL;
}
- // Ramp down IDB before we ramp down WebKit (and V8), since IDB classes might
- // hold pointers to V8 objects (e.g., via pending requests).
+ // Ramp down IDB and FileSystem before we ramp down WebKit (and V8), since
+ // these classes might hold pointers to V8 objects (e.g., via pending
+ // requests).
main_thread_indexed_db_dispatcher_.reset();
blink::shutdown();
« content/child/fileapi/webfilesystem_impl.cc ('K') | « content/child/fileapi/webfilesystem_impl.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698